pub struct AddArg {
pub store_id: Option<String>,
pub ean: String,
pub quantity: Option<f64>,
pub unit: Option<String>,
pub local_store_id: Option<String>,
pub allow_substitutes: Option<bool>,
}Fields
store_id: Option<String>ean: Stringquantity: Option<f64>unit: Option<String>local_store_id: Option<String>allow_substitutes: Option<bool>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for AddArg
impl<'de> Deserialize<'de> for AddArg
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AddArg
impl JsonSchema for AddArg
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AddArg
impl RefUnwindSafe for AddArg
impl Send for AddArg
impl Sync for AddArg
impl Unpin for AddArg
impl UnsafeUnpin for AddArg
impl UnwindSafe for AddArg