pub struct AuthArg {
pub store_id: Option<String>,
}Expand description
store_id is optional here, unlike everywhere else: any store reports the same
userInfo, and the caller most likely to reach for this tool is someone whose
setup is not working, who may not have a store id to hand.
Fields
store_id: Option<String>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for AuthArg
impl<'de> Deserialize<'de> for AuthArg
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AuthArg
impl JsonSchema for AuthArg
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AuthArg
impl RefUnwindSafe for AuthArg
impl Send for AuthArg
impl Sync for AuthArg
impl Unpin for AuthArg
impl UnsafeUnpin for AuthArg
impl UnwindSafe for AuthArg