pub struct AuthStatus {
pub logged_in: bool,
pub account: Option<String>,
pub detail: String,
}Fields
logged_in: boolaccount: Option<String>The signed-in account, when there is one.
detail: StringTrait Implementations
Sourceimpl Debug for AuthStatus
impl Debug for AuthStatus
Sourceimpl JsonSchema for AuthStatus
impl JsonSchema for AuthStatus
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AuthStatus
impl RefUnwindSafe for AuthStatus
impl Send for AuthStatus
impl Sync for AuthStatus
impl Unpin for AuthStatus
impl UnsafeUnpin for AuthStatus
impl UnwindSafe for AuthStatus