pub struct DefaultStoreStatus {
pub default_store: String,
}Fields
default_store: StringTrait Implementations
Sourceimpl Debug for DefaultStoreStatus
impl Debug for DefaultStoreStatus
Sourceimpl JsonSchema for DefaultStoreStatus
impl JsonSchema for DefaultStoreStatus
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for DefaultStoreStatus
impl RefUnwindSafe for DefaultStoreStatus
impl Send for DefaultStoreStatus
impl Sync for DefaultStoreStatus
impl Unpin for DefaultStoreStatus
impl UnsafeUnpin for DefaultStoreStatus
impl UnwindSafe for DefaultStoreStatus