pub struct RemoveArg {
pub store_id: Option<String>,
pub item_id: String,
}Fields
store_id: Option<String>item_id: StringTrait Implementations
Sourceimpl<'de> Deserialize<'de> for RemoveArg
impl<'de> Deserialize<'de> for RemoveArg
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RemoveArg
impl JsonSchema for RemoveArg
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RemoveArg
impl RefUnwindSafe for RemoveArg
impl Send for RemoveArg
impl Sync for RemoveArg
impl Unpin for RemoveArg
impl UnsafeUnpin for RemoveArg
impl UnwindSafe for RemoveArg