pub struct SearchProductsArg {
pub store_id: Option<String>,
pub query: String,
pub limit: Option<u32>,
}Fields
store_id: Option<String>query: Stringlimit: Option<u32>Trait Implementations
Sourceimpl Debug for SearchProductsArg
impl Debug for SearchProductsArg
Sourceimpl<'de> Deserialize<'de> for SearchProductsArg
impl<'de> Deserialize<'de> for SearchProductsArg
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SearchProductsArg
impl JsonSchema for SearchProductsArg
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SearchProductsArg
impl RefUnwindSafe for SearchProductsArg
impl Send for SearchProductsArg
impl Sync for SearchProductsArg
impl Unpin for SearchProductsArg
impl UnsafeUnpin for SearchProductsArg
impl UnwindSafe for SearchProductsArg