pub struct SearchStoresArg {
pub query: String,
pub limit: Option<u32>,
}Fields
query: Stringlimit: Option<u32>Trait Implementations
Sourceimpl Debug for SearchStoresArg
impl Debug for SearchStoresArg
Sourceimpl<'de> Deserialize<'de> for SearchStoresArg
impl<'de> Deserialize<'de> for SearchStoresArg
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SearchStoresArg
impl JsonSchema for SearchStoresArg
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SearchStoresArg
impl RefUnwindSafe for SearchStoresArg
impl Send for SearchStoresArg
impl Sync for SearchStoresArg
impl Unpin for SearchStoresArg
impl UnsafeUnpin for SearchStoresArg
impl UnwindSafe for SearchStoresArg