pub struct SetDefaultStoreArg {
pub store_id: String,
}Expand description
Used by set_default_store, where the store id is always required.
Fields
store_id: StringTrait Implementations
Sourceimpl Debug for SetDefaultStoreArg
impl Debug for SetDefaultStoreArg
Sourceimpl<'de> Deserialize<'de> for SetDefaultStoreArg
impl<'de> Deserialize<'de> for SetDefaultStoreArg
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SetDefaultStoreArg
impl JsonSchema for SetDefaultStoreArg
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SetDefaultStoreArg
impl RefUnwindSafe for SetDefaultStoreArg
impl Send for SetDefaultStoreArg
impl Sync for SetDefaultStoreArg
impl Unpin for SetDefaultStoreArg
impl UnsafeUnpin for SetDefaultStoreArg
impl UnwindSafe for SetDefaultStoreArg