pub struct StartLoginArg {
pub port: Option<u16>,
}Fields
port: Option<u16>Trait Implementations
Sourceimpl Debug for StartLoginArg
impl Debug for StartLoginArg
Sourceimpl<'de> Deserialize<'de> for StartLoginArg
impl<'de> Deserialize<'de> for StartLoginArg
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for StartLoginArg
impl JsonSchema for StartLoginArg
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for StartLoginArg
impl RefUnwindSafe for StartLoginArg
impl Send for StartLoginArg
impl Sync for StartLoginArg
impl Unpin for StartLoginArg
impl UnsafeUnpin for StartLoginArg
impl UnwindSafe for StartLoginArg