pub struct StoreArg {
pub store_id: Option<String>,
}Expand description
Used by tools whose only argument is a store id that may fall back to the default
(get_cart, clear_cart).
Fields
store_id: Option<String>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for StoreArg
impl<'de> Deserialize<'de> for StoreArg
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for StoreArg
impl JsonSchema for StoreArg
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for StoreArg
impl RefUnwindSafe for StoreArg
impl Send for StoreArg
impl Sync for StoreArg
impl Unpin for StoreArg
impl UnsafeUnpin for StoreArg
impl UnwindSafe for StoreArg